@@ -1,14 +1,27 @@
 from __future__ import annotations
 
 import asyncio
-from collections.abc import Callable
-from typing import Any, Coroutine, Optional, TypeVar, Union
+from typing import (
+    Any,
+    Callable,
+    Coroutine,
+    Optional,
+    TYPE_CHECKING,
+    TypeVar,
+    Union,
+)
 
 from .api import BaseObject
-from .filters import BaseFilter, FilterCallable
+from .filters import (
+    BaseFilter,
+    FilterCallable,
+)
+
+if TYPE_CHECKING:
+    from client import Client
 
 SomeUpdate = TypeVar('SomeUpdate', bound=BaseObject)
-HandlerCallable = Callable[['aiotdlib.Client', SomeUpdate], Coroutine[Any, Any, None]]
+HandlerCallable = Callable[['Client', SomeUpdate], Coroutine[Any, Any, None]]
 
 
 class Handler(object):
